@@ -4,14 +4,17 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Carp qw( confess );
-use Module::Runtime qw( use_module );
 
 # We load this up front to make sure that the prereq modules are installed.
 use File::ChangeNotify::Watcher::Default;
 use Module::Pluggable::Object;
+use Module::Runtime qw( use_module );
+
+# First version to support coerce => 1
+use Moo 1.006 ();
 
 sub instantiate_watcher {
     my $class = shift;
@@ -67,7 +70,7 @@ File::ChangeNotify - Watch for changes to files, cross-platform style
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
